"use strict";

var _lodash = _interopRequireDefault(require("lodash"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-shadow */
function extractMinWidths(breakpoints) {
  return _lodash.default.flatMap(breakpoints, breakpoints => {
    if (_lodash.default.isString(breakpoints)) {
      breakpoints = {
        min: breakpoints
      };
    }

    if (!_lodash.default.isArray(breakpoints)) {
      breakpoints = [breakpoints];
    }

    return (0, _lodash.default)(breakpoints).filter(breakpoint => {
      return _lodash.default.has(breakpoint, 'min') || _lodash.default.has(breakpoint, 'min-width');
    }).map(breakpoint => {
      return _lodash.default.get(breakpoint, 'min-width', breakpoint.min);
    }).value();
  });
}

module.exports = function () {
  return function ({
    addComponents,
    config
  }) {
    const minWidths = extractMinWidths(config('theme.container.screens', config('theme.screens')));

    const atRules = _lodash.default.map(minWidths, minWidth => {
      return {
        [`@media (min-width: ${minWidth})`]: {
          '.container': {
            'max-width': minWidth
          }
        }
      };
    });

    addComponents([{
      '.container': Object.assign({
        width: '100%'
      }, config('theme.container.center', false) ? {
        marginRight: 'auto',
        marginLeft: 'auto'
      } : {}, _lodash.default.has(config('theme.container', {}), 'padding') ? {
        paddingRight: config('theme.container.padding'),
        paddingLeft: config('theme.container.padding')
      } : {})
    }, ...atRules]);
  };
};